@@ -20,6 +20,7 @@
  * Author: Carl-Anton Ingmarsson <ca.ingmarsson@gmail.com>
  */
 
+#include <stdlib.h>
 #include <string.h>
 #include <glib/gi18n.h>
 
@@ -878,6 +879,12 @@ read_all_cb (GObject *source_object, GAsyncResult *res, gpointer user_data)
     g_simple_async_result_take_error (simple, err);
     goto done;
   }
+  else if (bytes_read == 0)
+  {
+    g_simple_async_result_set_error (simple, G_IO_ERROR, G_IO_ERROR_CLOSED,
+                                     _("Got EOS"));
+    goto done;
+  }
 
   read_data = g_simple_async_result_get_op_res_gpointer (simple);
 
@@ -1048,8 +1055,15 @@ read_data_cb (GObject *object, GAsyncResult *res, gpointer user_data)
   result = read_all_finish (input, res, NULL, &err);
   if (!result)
   {
-    g_warning ("FAIL!!! \"%s\"\n", err->message);
-    g_error_free (err);
+    if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CLOSED))
+    {
+      g_message (_("Host closed connection"));
+      exit(0);
+    }
+    else
+    {
+      g_error ("FAIL!!! \"%s\"\n", err->message);
+    }
   }
 
   dispatch_reply (afp_connection);
@@ -1082,8 +1096,15 @@ read_dsi_header_cb (GObject *object, GAsyncResult *res, gpointer user_data)
   result = read_all_finish (input, res, NULL, &err);
   if (!result)
   {
-    g_warning ("FAIL!!! \"%s\"\n", err->message);
-    g_error_free (err);
+    if (g_error_matches (err, G_IO_ERROR, G_IO_ERROR_CLOSED))
+    {
+      g_message (_("Host closed connection"));
+      exit(0);
+    }
+    else
+    {
+      g_error ("FAIL!!! \"%s\"\n", err->message);
+    }
   }
 
   dsi_header = &priv->read_dsi_header;
@@ -1264,6 +1285,9 @@ write_all_finish (GOutputStream *stream,
     } \
 \
     g_error_free (err); \
+\
+    g_hash_table_remove (priv->request_hash, \
+                         GUINT_TO_POINTER ((guint)GUINT16_FROM_BE (priv->write_dsi_header.requestID))); \
     free_request_data (req_data); \
 \
     g_mutex_lock (&priv->mutex); \
@@ -1283,11 +1307,6 @@ write_buf_cb (GObject *object, GAsyncResult *res, gpointer user_data)
   
   HANDLE_RES ();
 
-  g_hash_table_insert (priv->request_hash,
-                       GUINT_TO_POINTER ((guint)GUINT16_FROM_BE (priv->write_dsi_header.requestID)),
-                       req_data);
-
-
   g_mutex_lock (&priv->mutex);
   send_request_unlocked (afp_conn);
   g_mutex_unlock (&priv->mutex);
@@ -1311,10 +1330,6 @@ write_command_cb (GObject *object, GAsyncResult *res, gpointer user_data)
     return;
   }
   
-  g_hash_table_insert (priv->request_hash,
-                       GUINT_TO_POINTER ((guint)GUINT16_FROM_BE (priv->write_dsi_header.requestID)),
-                       req_data);
-
   g_mutex_lock (&priv->mutex);
   send_request_unlocked (afp_conn);
   g_mutex_unlock (&priv->mutex);
@@ -1429,6 +1444,10 @@ send_request_unlocked (GVfsAfpConnection *afp_connection)
       g_assert_not_reached ();
   }
 
+  if (req_data->type != REQUEST_TYPE_TICKLE)
+    g_hash_table_insert (priv->request_hash,
+                         GUINT_TO_POINTER ((guint)GUINT16_FROM_BE (priv->write_dsi_header.requestID)),
+                         req_data);
 
   write_all_async (g_io_stream_get_output_stream (priv->stream),
                    &priv->write_dsi_header, sizeof (DSIHeader), 0,
