@@ -48,7 +48,10 @@ typedef enum {
   IOS2,
   IOS3,
   IOS4,
-  IOS5
+  IOS5,
+  IOS6,
+  IOS7,
+  IOS8
 } HostOSVersion;
 
 typedef enum {
@@ -359,7 +362,9 @@ _idevice_event_cb (const idevice_event_t *event, void *user_data)
 
   idevice_event_unsubscribe ();
 
-  g_vfs_backend_force_unmount ((GVfsBackend*)afc_backend);
+  /* TODO: need a cleaner way to force unmount ourselves:
+   * https://bugzilla.gnome.org/show_bug.cgi?id=708288 */
+  exit (1);
 }
 
 static gboolean
@@ -591,6 +596,15 @@ g_vfs_backend_afc_mount (GVfsBackend *backend,
                 case 5:
                   self->version = IOS5;
                   break;
+                case 6:
+                  self->version = IOS6;
+                  break;
+                case 7:
+                  self->version = IOS7;
+                  break;
+                case 8:
+                  self->version = IOS8;
+                  break;
                 }
             }
         }
@@ -1668,7 +1682,7 @@ g_vfs_backend_afc_set_info_from_afcinfo (GVfsBackendAfc *self,
           g_free (parent);
           g_free (thumb_base);
         }
-      else if (self->version == IOS4 || self->version == IOS5)
+      else if (self->version >= IOS4)
         {
           char **components;
 
