@@ -297,9 +297,8 @@ archive_file_get_from_path (ArchiveFile *file, const char *filename, gboolean ad
 	    }
 	  else
 	    {
-	      /* happens when adding directories, their path ends with a / */
-              /* Can also happen with "." in e.g. iso files */
-	      g_assert (names[i + 1] == NULL);
+	      /* Ignore empty elements from directories ending with a slash.
+	       * Ignore elements consisting of a single "." */
 	      g_free (names[i]);
 	      names[i] = NULL;
 	      cur = file;
@@ -376,6 +375,8 @@ archive_entry_determine_size (GVfsArchive          *archive,
 	    DEBUG ("archive_read_data_block: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
 	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
 	    archive_clear_error (archive->archive);
+            if (result == ARCHIVE_RETRY)
+              continue;
 	  }
 
 	  size += read;
@@ -541,6 +542,8 @@ create_file_tree (GVfsBackendArchive *ba, GVfsJob *job)
   	    DEBUG ("archive_read_next_header: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
   	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
   	    archive_clear_error (archive->archive);
+            if (result == ARCHIVE_RETRY)
+              continue;
 	  }
   
 	  ArchiveFile *file = archive_file_get_from_path (ba->files, 
@@ -726,6 +729,8 @@ do_open_for_read (GVfsBackend *       backend,
 	    DEBUG ("do_open_for_read: result = %d, error = '%s'\n", result, archive_error_string (archive->archive));
 	    archive_set_error (archive->archive, ARCHIVE_OK, "No error");
 	    archive_clear_error (archive->archive);
+            if (result == ARCHIVE_RETRY)
+              continue;
 	  }
 
           entry_pathname = archive_entry_pathname (entry);
