@@ -68,10 +68,8 @@ DEBUG (const gchar *message, ...)
 #if DEBUG_SHOW_TRACES
   va_list args;
   va_start (args, message);
-  g_vfprintf (stderr, message, args);
+  g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, message, args);
   va_end (args);
-  g_fprintf (stderr, "\n");
-  fflush (stderr);
 #endif
 }
 
@@ -81,10 +79,8 @@ DEBUG_ENUMERATE (const gchar *message, ...)
 #if DEBUG_SHOW_ENUMERATE_TRACES
   va_list args;
   va_start (args, message);
-  g_vfprintf (stderr, message, args);
+  g_logv (G_LOG_DOMAIN, G_LOG_LEVEL_DEBUG, message, args);
   va_end (args);
-  g_fprintf (stderr, "\n");
-  fflush (stderr);
 #endif
 }
 
