@@ -205,7 +205,13 @@ g_vfs_ftp_task_acquire_connection (GVfsFtpTask *task)
 
       task->conn = g_queue_pop_head (ftp->queue);
       if (task->conn != NULL)
-        break;
+        {
+          if (g_vfs_ftp_connection_is_usable (task->conn))
+            break;
+
+          g_vfs_ftp_connection_free (task->conn);
+          task->conn = NULL;
+        }
 
       if (ftp->connections < ftp->max_connections)
         {
@@ -227,10 +233,11 @@ g_vfs_ftp_task_acquire_connection (GVfsFtpTask *task)
               g_vfs_ftp_task_setup_connection (task);
               if (G_LIKELY (!g_vfs_ftp_task_is_in_error (task)))
                 break;
+
+              g_vfs_ftp_connection_free (task->conn);
+              task->conn = NULL;
             }
 
-          g_vfs_ftp_connection_free (task->conn);
-          task->conn = NULL;
           g_mutex_lock (&ftp->mutex);
           ftp->connections--;
           /* If this value is still equal to our thread it means there were no races 
