@@ -46,6 +46,7 @@ struct _GMtpVolume {
 
   char *name;
   char *icon;
+  char *symbolic_icon;
 };
 
 static void g_mtp_volume_volume_iface_init (GVolumeIface *iface);
@@ -102,23 +103,24 @@ udev_decode_string (const char* encoded)
 {
   int len;
   const char* s;
-  char *decoded;
+  static char decoded[4096];
 
   if (encoded == NULL)
     return NULL;
 
-  decoded = g_malloc(4096);
-
   for (len = 0, s = encoded; *s && len < sizeof (decoded) - 1; ++len, ++s) {
     /* need to check for NUL terminator in advance */
     if (s[0] == '\\' && s[1] == 'x' && s[2] >= '0' && s[3] >= '0') {
       decoded[len] = (hexdigit (s[2]) << 4) | hexdigit (s[3]);
       s += 3;
+    } else if (s[0] == '_' || s[0] == '-') {
+      decoded[len] = ' ';
     } else {
       decoded[len] = *s;
     }
   }
   decoded[len] = '\0';
+
   return decoded;
 }
 
@@ -150,7 +152,7 @@ set_volume_name (GMtpVolume *v)
 
   v->name = NULL;
   if (product != NULL && strlen (product) > 0) {
-    v->name = g_strdup (product);
+    v->name = g_strdup (udev_decode_string (product));
   } else if (vendor == NULL) {
     if (model != NULL)
       v->name = g_strdup (udev_decode_string (model));
@@ -187,6 +189,17 @@ set_volume_icon (GMtpVolume *volume)
     volume->icon = g_strdup ("camera-photo");
 }
 
+static void
+set_volume_symbolic_icon (GMtpVolume *volume)
+{
+  if (g_udev_device_has_property (volume->device, "ID_MEDIA_PLAYER_ICON_NAME"))
+    volume->symbolic_icon = g_strconcat (g_udev_device_get_property (volume->device, "ID_MEDIA_PLAYER_ICON_NAME"), "-symbolic", NULL);
+  else if (g_udev_device_has_property (volume->device, "ID_MEDIA_PLAYER"))
+    volume->symbolic_icon = g_strdup ("multimedia-player-symbolic");
+  else
+    volume->symbolic_icon = g_strdup ("camera-photo-symbolic");
+}
+
 GMtpVolume *
 g_mtp_volume_new (GVolumeMonitor   *volume_monitor,
                   GUdevDevice      *device,
@@ -214,6 +227,7 @@ g_mtp_volume_new (GVolumeMonitor   *volume_monitor,
 
   set_volume_name (volume);
   set_volume_icon (volume);
+  set_volume_symbolic_icon (volume);
   /* we do not really need to listen for changes */
 
   return volume;
@@ -236,6 +250,18 @@ g_mtp_volume_get_icon (GVolume *volume)
   return icon;
 }
 
+static GIcon *
+g_mtp_volume_get_symbolic_icon (GVolume *volume)
+{
+  GMtpVolume *mtp_volume = G_MTP_VOLUME (volume);
+  GIcon *icon;
+
+  G_LOCK (mtp_volume);
+  icon = g_themed_icon_new_with_default_fallbacks (mtp_volume->symbolic_icon);
+  G_UNLOCK (mtp_volume);
+  return icon;
+}
+
 static char *
 g_mtp_volume_get_name (GVolume *volume)
 {
@@ -416,6 +442,7 @@ g_mtp_volume_volume_iface_init (GVolumeIface *iface)
 {
   iface->get_name = g_mtp_volume_get_name;
   iface->get_icon = g_mtp_volume_get_icon;
+  iface->get_symbolic_icon = g_mtp_volume_get_symbolic_icon;
   iface->get_uuid = g_mtp_volume_get_uuid;
   iface->get_drive = g_mtp_volume_get_drive;
   iface->get_mount = g_mtp_volume_get_mount;
