@@ -32,6 +32,7 @@
 #include <gio/gio.h>
 
 #ifdef HAVE_KEYRING
+#define SECRET_API_SUBJECT_TO_CHANGE
 #include <libsecret/secret.h>
 #endif
 
@@ -192,6 +193,7 @@ apply_options_from_fstab (GVfsUDisks2Volume *volume,
 }
 
 
+#if UDISKS_CHECK_VERSION(2,0,90)
 static gpointer
 _g_object_ref0 (gpointer object)
 {
@@ -200,6 +202,7 @@ _g_object_ref0 (gpointer object)
   else
     return NULL;
 }
+#endif
 
 static gboolean
 update_volume (GVfsUDisks2Volume *volume)
@@ -1544,8 +1547,8 @@ gvfs_udisks2_volume_mount (GVolume             *_volume,
                                                             block);
           if (udisks_drive != NULL)
             {
-              gchar *drive_name;
-              gchar *drive_desc;
+              gchar *drive_name = NULL;
+              gchar *drive_desc = NULL;
 
 #if UDISKS_CHECK_VERSION(2,0,90)
               {
